@@ -129,6 +129,7 @@ pan :: clean_utf8 (const StringView& in_arg)
   return out;
 }
 
+#ifdef HAVE_GMIME_30
 std::string
 pan :: header_to_utf8 (const StringView  & header,
                        const char        * fallback_charset1,
@@ -136,13 +137,29 @@ pan :: header_to_utf8 (const StringView  & header,
 {
   std::string s = content_to_utf8 (header, fallback_charset1, fallback_charset2);
   if (header.strstr ("=?")) {
-    char * decoded (g_mime_utils_8bit_header_decode ((const guchar*) s.c_str()));
+    char * decoded (g_mime_utils_header_decode_text (NULL, s.c_str()));
     s = clean_utf8 (decoded);
     g_free (decoded);
   }
   return s;
 }
 
+#else
+std::string
+pan :: header_to_utf8 (const StringView  & header,
+                       const char        * fallback_charset1,
+                       const char        * fallback_charset2)
+{
+  std::string s = content_to_utf8 (header, fallback_charset1, fallback_charset2);
+  if (header.strstr ("=?")) {
+    char * decoded (g_mime_utils_header_decode_text ( s.c_str()));
+    s = clean_utf8 (decoded);
+    g_free (decoded);
+  }
+  return s;
+}
+#endif
+
 std::string
 pan :: mime_part_to_utf8 (GMimePart     * part,
                           const char    * fallback_charset)
@@ -150,12 +167,21 @@ pan :: mime_part_to_utf8 (GMimePart     * part,
   std::string ret;
 
   g_return_val_if_fail (GMIME_IS_PART(part), ret);
+  const char * charset =
+    g_mime_object_get_content_type_parameter (GMIME_OBJECT (part), "charset");
+#ifdef HAVE_GMIME_30
+  GMimeDataWrapper * content = g_mime_part_get_content (part);
+#else
+  GMimeDataWrapper * content = g_mime_part_get_content_object (part);
+#endif
+  GMimeStream *stream = g_mime_stream_mem_new ();
 
-  size_t content_len (0);
-  const char * specified_charset (g_mime_object_get_content_type_parameter (GMIME_OBJECT (part), "charset"));
-  const char * content = g_mime_part_get_content (part, &content_len);
-  if (content && content_len)
-    ret = content_to_utf8 (StringView (content, content_len), specified_charset, fallback_charset);
+  g_mime_data_wrapper_write_to_stream (content, stream);
+  GByteArray *buf = ((GMimeStreamMem *) stream)->buffer;
+  ret = content_to_utf8 (StringView ((const char *) buf->data, buf->len),
+    charset, fallback_charset);
+
+  g_object_unref (stream);
 
   return ret;
 }
@@ -191,7 +217,7 @@ pan :: content_to_utf8 (const StringView  & content,
 
       // try each charset in turn
       for (size_t i=0; i!=n; ++i) {
-        char * tmp = g_convert (content.str, content.len, "UTF-8", encodings[i], 0, 0, 0);
+        char * tmp = g_convert (content.str, content.len, "UTF-8", encodings[i], 0, 0, NULL);
         if (tmp) {
           ret = tmp;
           g_free (tmp);
@@ -205,7 +231,7 @@ pan :: content_to_utf8 (const StringView  & content,
       ret.assign (content.str, content.len);
     if (!g_utf8_validate (ret.c_str(), ret.size(), NULL)) {
       ret = clean_utf8 (ret);
-      Log::add_err (_("Couldn't determine article encoding.  Non-UTF8 characters were removed."));
+      Log::add_err (_("Couldn’t determine article encoding.  Non-UTF8 characters were removed."));
     }
   }
 
