@@ -51,6 +51,8 @@ extern "C" {
 
 #define FIRST_PICTURE "first-picture"
 
+#define FACE_SIZE 48
+
 using namespace pan;
 
 /***
@@ -903,7 +905,11 @@ namespace
     GError * err (0);
 
     // populate the loader
+#ifdef HAVE_GMIME_30
+    GMimeDataWrapper * wrapper (g_mime_part_get_content (part));
+#else    
     GMimeDataWrapper * wrapper (g_mime_part_get_content_object (part));
+#endif    
     if (wrapper)
     {
       GMimeStream * mem_stream (g_mime_stream_mem_new ());
@@ -1186,24 +1192,31 @@ BodyPane :: set_text_from_message (GMimeMessage * message)
   s.resize (std::max((size_t)0,s.size()-1)); // remove trailing linefeed
   gtk_label_set_markup (GTK_LABEL(_headers), s.c_str());
 
+#if !GTK_CHECK_VERSION(3,0,0)
   // ellipsize mode is useless w/o this in expander...
   gtk_label_set_width_chars (GTK_LABEL(_headers), (int)w);
+#endif
 
   // set the x-face...
   gtk_image_clear(GTK_IMAGE(_xface));
   const char * pch = message ? g_mime_object_get_header ((GMimeObject *) message, "X-Face") : 0;
   if (pch && gtk_widget_get_window(_xface) )
   {
+    gtk_widget_set_size_request (_xface, FACE_SIZE, FACE_SIZE);
     GdkPixbuf *pixbuf = NULL;
     pixbuf = pan_gdk_pixbuf_create_from_x_face (pch);
     gtk_image_set_from_pixbuf (GTK_IMAGE(_xface), pixbuf);
     g_object_unref (pixbuf);
+  } else {
+    gtk_widget_set_size_request(_xface, 0, FACE_SIZE);
   }
+
   // set the face
   gtk_image_clear(GTK_IMAGE(_face));
   pch = message ? g_mime_object_get_header ((GMimeObject *) message, "Face") : 0;
   if (pch && gtk_widget_get_window(_face))
   {
+    gtk_widget_set_size_request (_face, FACE_SIZE, FACE_SIZE);
     GMimeEncoding dec;
     g_mime_encoding_init_decode(&dec, GMIME_CONTENT_ENCODING_BASE64);
     guchar* buf = new guchar[strlen(pch)];
@@ -1215,6 +1228,8 @@ BodyPane :: set_text_from_message (GMimeMessage * message)
     gtk_image_set_from_pixbuf (GTK_IMAGE(_face), pixbuf);
     g_object_unref(pl);
     delete[] buf;
+  } else {
+    gtk_widget_set_size_request(_face, 0, FACE_SIZE);
   }
 
   // set the terse headers...
@@ -1239,7 +1254,11 @@ BodyPane :: set_text_from_message (GMimeMessage * message)
   // maybe add the headers
   const bool do_show_headers (_prefs.get_flag ("show-all-headers", false));
   if (message && do_show_headers) {
+#ifdef HAVE_GMIME_30
+    char * headers (g_mime_object_get_headers ((GMimeObject *) message, NULL));
+#else    
     char * headers (g_mime_object_get_headers ((GMimeObject *) message));
+#endif    
     GtkTextIter end;
     gtk_text_buffer_get_end_iter (_buffer, &end);
     StringView line, v(headers);
@@ -1312,7 +1331,7 @@ BodyPane :: on_verbose_tooltip_cb(GtkWidget  *widget,
   std::pair<std::string,std::string> name_and_email = get_email_address(info.signers[0].name);
   g_snprintf(buf, sizeof(buf),
              _("<u>This is a <b>PGP-Signed</b> message.</u>\n\n"
-             "<b>Signer:</b> %s ('%s')\n"
+             "<b>Signer:</b> %s (“%s”)\n"
              "<b>Valid until:</b> %s\n"
              "<b>Created on:</b> %s"),
              name_and_email.first.c_str(), name_and_email.second.c_str(),
@@ -1632,9 +1651,11 @@ BodyPane :: clear_attachments()
   _current_attachment = 0;
 
   {
-    gtk_container_remove (GTK_CONTAINER (_att_frame), _att_toolbar);
+    gtk_widget_set_no_show_all (_att_box, TRUE);
+    gtk_widget_hide (_att_box);
+    gtk_container_remove (GTK_CONTAINER (_att_box), _att_toolbar);
     _att_toolbar = NULL;
-    (void)create_attachments_toolbar(_att_frame);
+    (void)create_attachments_toolbar(_att_box);
   }
 
 }
@@ -1674,7 +1695,8 @@ BodyPane :: add_attachment_to_toolbar (const char* fn)
   gtk_grid_attach (GTK_GRID(_att_toolbar), w, _cur_col++, _cur_row, 1, 1);
 #endif  // 3.0.0
 
-  gtk_widget_show_all(_att_toolbar);
+  gtk_widget_set_no_show_all (_att_box, FALSE);
+  gtk_widget_show_all (_att_box);
 }
 
 #ifdef HAVE_WEBKIT
@@ -1686,7 +1708,7 @@ BodyPane :: set_html_text (const char* text)
 #endif
 
 GtkWidget*
-BodyPane :: create_attachments_toolbar (GtkWidget* frame)
+BodyPane :: create_attachments_toolbar (GtkWidget* box)
 {
 
   _cur_col = 0;
@@ -1703,10 +1725,9 @@ BodyPane :: create_attachments_toolbar (GtkWidget* frame)
   gtk_grid_set_column_spacing (GTK_GRID(w), 3);
   gtk_grid_set_row_spacing (GTK_GRID (w), 4);
 #endif
-  gtk_container_add (GTK_CONTAINER (frame), w);
-  gtk_widget_show_all (frame);
+  gtk_container_add (GTK_CONTAINER (box), w);
 
-  return frame;
+  return box;
 }
 
 /***
@@ -1744,7 +1765,7 @@ BodyPane :: BodyPane (Data& data, ArticleCache& cache, Prefs& prefs, GroupPrefs
 
   // menu for popup menu for attachments
   _menu = gtk_menu_new ();
-  l = gtk_menu_item_new_with_label(_("Save Attachment As..."));
+  l = gtk_menu_item_new_with_label(_("Save Attachment As…"));
   g_signal_connect (l, "activate", G_CALLBACK(menu_clicked_as_cb), this);
   gtk_menu_shell_append (GTK_MENU_SHELL(_menu), l);
   l =  gtk_menu_item_new_with_label(_("Save All Attachments"));
@@ -1753,7 +1774,7 @@ BodyPane :: BodyPane (Data& data, ArticleCache& cache, Prefs& prefs, GroupPrefs
   gtk_menu_shell_append (GTK_MENU_SHELL(_menu),l);
   gtk_widget_show_all(_menu);
 
-  GtkWidget * vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, PAD);
+  GtkWidget * vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
   gtk_container_set_resize_mode (GTK_CONTAINER(vbox), GTK_RESIZE_QUEUE);
 
   // about this expander... getting the ellipsis to work is a strange process.
@@ -1768,6 +1789,11 @@ BodyPane :: BodyPane (Data& data, ArticleCache& cache, Prefs& prefs, GroupPrefs
   gtk_widget_set_size_request (w, 50, -1);
   g_signal_connect (w, "activate", G_CALLBACK(expander_activated_cb), this);
   gtk_box_pack_start (GTK_BOX(vbox), w, false, false, 0);
+#if !GTK_CHECK_VERSION(3,0,0)
+  gtk_box_pack_start (GTK_BOX(vbox), gtk_hseparator_new(), false, false, 0);
+#else
+  gtk_box_pack_start (GTK_BOX(vbox), gtk_separator_new(GTK_ORIENTATION_HORIZONTAL), false, false, 0);
+#endif
 
   _terse = gtk_label_new ("Expander");
   g_object_ref_sink (G_OBJECT(_terse));
@@ -1788,10 +1814,10 @@ BodyPane :: BodyPane (Data& data, ArticleCache& cache, Prefs& prefs, GroupPrefs
   gtk_box_pack_start (GTK_BOX(hbox), w, true, true, PAD_SMALL);
 
   w = _xface = gtk_image_new();
-  gtk_widget_set_size_request (w, 48, 48);
+  gtk_widget_set_size_request (w, 0, FACE_SIZE);
   gtk_box_pack_start (GTK_BOX(hbox), w, false, false, PAD_SMALL);
   w = _face = gtk_image_new ();
-  gtk_widget_set_size_request (w, 48, 48);
+  gtk_widget_set_size_request (w, 0, FACE_SIZE);
   gtk_box_pack_start (GTK_BOX(hbox), w, false, false, PAD_SMALL);
   gtk_widget_show_all (_verbose);
   g_signal_connect (_verbose, "button-press-event", G_CALLBACK(verbose_clicked_cb), this);
@@ -1808,7 +1834,6 @@ BodyPane :: BodyPane (Data& data, ArticleCache& cache, Prefs& prefs, GroupPrefs
   gtk_text_view_set_editable (GTK_TEXT_VIEW(_text), false);
   gtk_text_view_set_cursor_visible (GTK_TEXT_VIEW(_text), false);
   _scroll = gtk_scrolled_window_new (NULL, NULL);
-  gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW(_scroll), GTK_SHADOW_IN);
   gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (_scroll),
                                   GTK_POLICY_AUTOMATIC,
                                   GTK_POLICY_AUTOMATIC);
@@ -1817,8 +1842,22 @@ BodyPane :: BodyPane (Data& data, ArticleCache& cache, Prefs& prefs, GroupPrefs
   gtk_box_pack_start (GTK_BOX(vbox), _scroll, true, true, 0);
 
   // add a toolbar for attachments
-  GtkWidget * frame = _att_frame = gtk_frame_new (_("Attachments"));
-  gtk_box_pack_start (GTK_BOX(vbox), create_attachments_toolbar(frame), false, false, 0);
+  _att_box = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
+  GtkWidget * att_label = gtk_label_new (_("Attachments:"));
+  gtk_misc_set_padding (GTK_MISC(att_label), PAD_SMALL, 0);
+  gtk_misc_set_alignment (GTK_MISC(att_label), 0, 0);
+#if !GTK_CHECK_VERSION(3,0,0)
+  gtk_box_pack_start (GTK_BOX(_att_box), gtk_hseparator_new(), false, false, 0);
+#else
+  gtk_box_pack_start (GTK_BOX(_att_box), gtk_separator_new(GTK_ORIENTATION_HORIZONTAL), false, false, 0);
+#endif
+  gtk_box_pack_start (GTK_BOX(_att_box), att_label, false, false, 0);
+  gtk_box_pack_start (GTK_BOX(vbox), create_attachments_toolbar (_att_box), false, false, 0);
+#if !GTK_CHECK_VERSION(3,0,0)
+  gtk_box_pack_start (GTK_BOX(vbox), gtk_hseparator_new(), false, false, 0);
+#else
+  gtk_box_pack_start (GTK_BOX(vbox), gtk_separator_new(GTK_ORIENTATION_HORIZONTAL), false, false, 0);
+#endif
 
   // set up the buffer tags
   _buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW(_text));
@@ -2031,10 +2070,18 @@ BodyPane :: create_followup_or_reply (bool is_reply)
 
     if (is_reply || fup_to=="poster") {
       const std::string& to (reply_to.empty() ? from : reply_to);
+#ifdef HAVE_GMIME_30
+      pan_g_mime_message_add_recipients_from_string (msg, GMIME_ADDRESS_TYPE_TO, to.c_str());
+#else
       pan_g_mime_message_add_recipients_from_string (msg, GMIME_RECIPIENT_TYPE_TO, to.c_str());
+#endif
     } else {
       const std::string& groups (fup_to.empty() ? newsgroups : fup_to);
+#ifdef HAVE_GMIME_30
+      g_mime_object_append_header ((GMimeObject *) msg, "Newsgroups", groups.c_str(), NULL);
+#else
       g_mime_object_append_header ((GMimeObject *) msg, "Newsgroups", groups.c_str());
+#endif
     }
 
     // Subject:
@@ -2043,21 +2090,43 @@ BodyPane :: create_followup_or_reply (bool is_reply)
     std::string val (normalize_subject_re (h));
     if (val.find ("Re:") != 0) // add "Re: " if we don't have one
       val.insert (0, "Re: ");
+#ifdef HAVE_GMIME_30
+    g_mime_message_set_subject (msg, val.c_str(), NULL);
+#else
     g_mime_message_set_subject (msg, val.c_str());
+#endif
 
     // attribution lines
     const char * cpch = g_mime_object_get_header (_message_obj, "From");
     h = header_to_utf8 (cpch, message_charset, group_charset);
+#ifdef HAVE_GMIME_30
+    g_mime_object_append_header (msg_obj, "X-Draft-Attribution-Author", h.c_str(), NULL);
+#else
     g_mime_object_append_header (msg_obj, "X-Draft-Attribution-Author", h.c_str());
+#endif
 
     cpch = g_mime_message_get_message_id (_message);
     h = header_to_utf8 (cpch, message_charset, group_charset);
+#ifdef HAVE_GMIME_30
+    g_mime_object_append_header (msg_obj, "X-Draft-Attribution-Id", h.c_str(), NULL);
+#else    
     g_mime_object_append_header (msg_obj, "X-Draft-Attribution-Id", h.c_str());
+#endif    
 
+#ifdef HAVE_GMIME_30
+    const char * header_t = "Date";
+    const char * tmp_s = g_mime_object_get_header (_message_obj, header_t);
+    const char * tmp = tmp_s;  // FIXME: convert time to string
+#else
     char * tmp = g_mime_message_get_date_as_string (_message);
+#endif
     h = header_to_utf8 (tmp, message_charset, group_charset);
+#ifdef HAVE_GMIME_30
+    g_mime_object_append_header (msg_obj, "X-Draft-Attribution-Date", h.c_str(), NULL);
+#else
     g_mime_object_append_header (msg_obj, "X-Draft-Attribution-Date", h.c_str());
     g_free (tmp);
+#endif
 
     // references
     const char * header = "References";
@@ -2069,7 +2138,11 @@ BodyPane :: create_followup_or_reply (bool is_reply)
     val += g_mime_message_get_message_id (_message);
     val += ">";
     val = GNKSA :: trim_references (val);
+#ifdef HAVE_GMIME_30
+    g_mime_object_append_header (msg_obj, header, val.c_str(), NULL);
+#else    
     g_mime_object_append_header (msg_obj, header, val.c_str());
+#endif    
 
     ///
     ///  BODY
@@ -2107,9 +2180,17 @@ BodyPane :: create_followup_or_reply (bool is_reply)
     g_mime_stream_write_string (stream, s.c_str());
     GMimeDataWrapper * wrapper = g_mime_data_wrapper_new_with_stream (stream, GMIME_CONTENT_ENCODING_8BIT);
     GMimePart * part = g_mime_part_new ();
+#ifdef HAVE_GMIME_30
+    GMimeContentType * new_type = g_mime_content_type_parse (NULL, "text/plain; charset=UTF-8");
+#else    
     GMimeContentType * new_type = g_mime_content_type_new_from_string ("text/plain; charset=UTF-8");
+#endif    
     g_mime_object_set_content_type ((GMimeObject *) part, new_type);
+#ifdef HAVE_GMIME_30
+    g_mime_part_set_content (part, wrapper);
+#else    
     g_mime_part_set_content_object (part, wrapper);
+#endif    
     g_mime_part_set_content_encoding (part, GMIME_CONTENT_ENCODING_8BIT);
     g_mime_message_set_mime_part (msg, GMIME_OBJECT(part));
     g_object_unref (new_type);
