@@ -126,7 +126,7 @@ PrefsDialog :: edit_shortkey (gpointer user_data)
       GTK_STOCK_OK, GTK_RESPONSE_ACCEPT, NULL);
 
   str = g_strdup_printf(
-      _("Press the combination of the keys\nyou want to use for \"%s\"."), data->value.c_str());
+      _("Press the combination of the keys\nyou want to use for “%s”."), data->value.c_str());
   label = gtk_label_new(str);
   gtk_misc_set_padding(GTK_MISC(label), 5, 10);
 
@@ -570,7 +570,7 @@ namespace pan
     for (size_t i=0; i<G_N_ELEMENTS(strings); ++i) {
       GtkTreeIter iter;
       gtk_list_store_append (store, &iter);
-      gtk_list_store_set (store, &iter, 0, strings[i][0], 1, strings[i][1], -1);
+      gtk_list_store_set (store, &iter, 0, gettext(strings[i][0]), 1, strings[i][1], -1);
       if (mode == strings[i][1])
         sel_index = i;
     }
@@ -1120,7 +1120,7 @@ PrefsDialog :: PrefsDialog (Prefs& prefs, GtkWindow* parent):
   t = HIG :: workarea_create ();
 
     gtk_widget_set_tooltip_text (t, _("This menu lets you configure Pan to take certain actions on your behalf automatically, "
-                                      "based on an article's score."));
+                                      "based on an article’s score."));
 
     int i(0);
     GtkWidget** action_combo = new GtkWidget*[2];
