@@ -80,14 +80,14 @@ namespace
   {
     char buf[1024];
     if (mode == TaskXOver::ALL)
-      snprintf(buf, sizeof(buf), _("Getting all headers for \"%s\""),
+      snprintf(buf, sizeof(buf), _("Getting all headers for “%s”"),
           group.c_str());
     else if (mode == TaskXOver::NEW)
-      snprintf(buf, sizeof(buf), _("Getting new headers for \"%s\""),
+      snprintf(buf, sizeof(buf), _("Getting new headers for “%s”"),
           group.c_str());
     else
       // SAMPLE
-      snprintf(buf, sizeof(buf), _("Sampling headers for \"%s\""),
+      snprintf(buf, sizeof(buf), _("Sampling headers for “%s”"),
           group.c_str());
     return std::string(buf);
   }
@@ -400,7 +400,12 @@ TaskXOver::on_nntp_line_process(NNTP * nntp, const StringView & line)
 	const char * fallback_charset = NULL; // FIXME
 
 	// are we done?
+#ifdef HAVE_GMIME_30
+	GDateTime * time_posted_gd = g_mime_utils_header_decode_date(date.str);
+	const time_t time_posted = g_date_time_to_unix(time_posted_gd);
+#else	
 	const time_t time_posted = g_mime_utils_header_decode_date(date.str, NULL);
+#endif	
 	if (_mode == DAYS && time_posted < _days_cutoff) {
 		_server_to_minitasks[nntp->_server].clear();
 		return;
@@ -497,7 +502,7 @@ TaskXOver::update_work(bool subtract_one_from_nntp_count)
       _state.set_completed();
       set_finished(OK);
       char str[4096];
-      g_snprintf(str, sizeof(str), _("Getting new headers for \"%s\" done."), _group.c_str());
+      g_snprintf(str, sizeof(str), _("Getting new headers for “%s” done."), _group.c_str());
       verbose (str);
     }
 }
